@@ -130,6 +130,8 @@ class VersionClassBase(object):
         data = {}
         class_manager = self.__parent_class__.__mapper__.class_manager
         for key, attr in class_manager.items():
+            if key == 'revision':
+                continue
             if isinstance(attr.property, sa.orm.ColumnProperty):
                 if not self.previous:
                     old = None
@@ -147,8 +149,9 @@ class VersionClassBase(object):
         if self in visited_objects:
             return
 
+        session = sa.orm.object_session(self)
+
         if self.operation_type == 2:
-            session = sa.orm.object_session(self)
             session.delete(self.parent)
             return
 
@@ -158,7 +161,16 @@ class VersionClassBase(object):
         # Check if parent object has been deleted
         if self.parent is None:
             self.parent = self.__parent_class__()
-            session = sa.orm.object_session(self)
+            table = self.__class__.__table__
+            self.parent.revision = (
+                session.execute(
+                    sa.select(
+                        [sa.func.max(self.__class__.revision)],
+                        from_obj=table
+                    )
+                    .where(table.c.id == self.id)
+                ).fetchone()[0]
+            )
             session.add(self.parent)
 
         # Before reifying relations we need to reify object properties. This
@@ -167,12 +179,12 @@ class VersionClassBase(object):
         # into parent object (if parent object has not null constraints).
         for key, attr in parent_mapper.class_manager.items():
             if isinstance(attr.property, sa.orm.ColumnProperty):
-                if key != 'transaction_id':
+                if key not in ['revision', 'transaction_id']:
                     setattr(self.parent, key, getattr(self, key))
 
         for key, attr in parent_mapper.class_manager.items():
             if isinstance(attr.property, sa.orm.RelationshipProperty):
-                if key not in ['versions', 'transaction']:
+                if key not in ['revision', 'versions', 'transaction']:
                     if attr.property.secondary is not None:
                         setattr(self.parent, key, [])
                         for value in getattr(self, key):
